@@ -156,8 +156,6 @@ class OvsHost(linux.LinuxDevice):
                 # Confiure the default offlow for self port with IP.
                 ipaddr = ipaddress.ip_interface(kwargs["ip"]).ip
                 self.ofctl_add_flow(bridge_name,
-                    #"priority=65535,arp,arp_tpa=%s,actions=normal" %(ip.split("/")[0]),
-                    #"priority=1,ip,nw_dst=%s actions=normal" %(ip.split("/")[0]),
                     'priority=10000,arp,arp_tpa=%s,arp_op=1,actions=move:"NXM_OF_ETH_SRC[]->NXM_OF_ETH_DST[]",mod_dl_src:"%s",load:"0x02->NXM_OF_ARP_OP[]",move:"NXM_NX_ARP_SHA[]->NXM_NX_ARP_THA[]",load:"0x%s->NXM_NX_ARP_SHA[]",move:"NXM_OF_ARP_SPA[]->NXM_OF_ARP_TPA[]",load:"0x%s->NXM_OF_ARP_SPA[]",in_port'%(ipaddr, macaddr, re.sub(r":", "", macaddr), "".join(f"{i:02x}" for i in ipaddr.packed)),
                     'priority=10000,icmp,nw_dst=%s,icmp_type=8,icmp_code=0,actions=push:"NXM_OF_ETH_SRC[]",push:"NXM_OF_ETH_DST[]",pop:"NXM_OF_ETH_SRC[]",pop:"NXM_OF_ETH_DST[]",push:"NXM_OF_IP_SRC[]",push:"NXM_OF_IP_DST[]",pop:"NXM_OF_IP_SRC[]",pop:"NXM_OF_IP_DST[]",load:"0xff->NXM_NX_IP_TTL[]",load:"0->NXM_OF_ICMP_TYPE[]",in_port' %(ipaddr),
                     )
@@ -189,8 +187,12 @@ class OvsHost(linux.LinuxDevice):
                     self.ofctl_add_flow(bridge_name,
                         "priority=10000,arp,arp_tpa=%s,actions=output:%s"
                         %(ipaddr.ip, arg["ofport"]),
-                        "priority=10000,ip,nw_src=%s,nw_dst=%s,actions=output:%s" 
-                        %(ipaddr.network, ipaddr.ip, arg["ofport"]))
+                        # We always know the mac/port mapping, so add it.
+                        "priority=10001,dl_dst=%s,actions=output:%s" 
+                        %(arg["mac"], arg["ofport"]),
+                        )
+
+
             elif dtype == "vm":
                 self.__add_vm(bridge_name, arg)
             else:
@@ -306,14 +308,17 @@ class OvsHost(linux.LinuxDevice):
             p["ofport"] = self.ovs_get_interface(port_name, "ofport")
             self.macs.append(p["mac"])
             self.devices.append(p)
+
             # Configure offlow for the same subnet
             if self["fail-mode"] == "secure":
                 ipaddr = ipaddress.ip_interface(p["ip"])
                 self.ofctl_add_flow(bridge_name,
                     "priority=10000,arp,arp_tpa=%s,actions=output:%s"
                     %(ipaddr.ip, p["ofport"]),
-                    "priority=10000,ip,nw_src=%s,nw_dst=%s,actions=output:%s" 
-                    %(ipaddr.network, ipaddr.ip, p["ofport"]))
+                    # We always know the mac/port mapping, so add it.
+                    "priority=10001,dl_dst=%s,actions=output:%s" 
+                    %(p["mac"], p["ofport"]),
+                    )
 
     def add_vtep (self, bridge_name, vtep, *args):
         '''
